@@ -324,38 +324,38 @@ docstrings = {
 
         Command line examples:
 
-            +-----------------------------------+----------------------------+
-            | Keyword Example                   | Description                |
-            +===================================+============================+
-            | --input_ts=fname.csv              | read all columns           |
-            |                                   | from 'fname.csv'           |
-            +-----------------------------------+----------------------------+
-            | --input_ts=fname.csv,2,1          | read data columns 2 and 1  |
-            |                                   | from 'fname.csv'           |
-            +-----------------------------------+----------------------------+
-            | --input_ts=fname.csv,2,skiprows=2 | read data column 2         |
-            |                                   | from 'fname.csv', skipping |
-            |                                   | first 2 rows so header is  |
-            |                                   | read from third row        |
-            +-----------------------------------+----------------------------+
-            | --input_ts=fname.xlsx,2,Sheet21   | read all data from 2nd     |
-            |                                   | sheet all data from        |
-            |                                   | "Sheet21" of 'fname.xlsx'  |
-            +-----------------------------------+----------------------------+
-            | --input_ts=fname.hdf5,Table12,T2  | read all data from table   |
-            |                                   | "Table12" then all data    |
-            |                                   | from table "T2" of         |
-            |                                   | 'fname.hdf5'               |
-            +-----------------------------------+----------------------------+
-            | --input_ts=fname.wdm,210,110      | read DSNs 210, then 110    |
-            |                                   | from 'fname.wdm'           |
-            +-----------------------------------+----------------------------+
-            | --input_ts='-'                    | read all columns from      |
-            |                                   | standard input (stdin)     |
-            +-----------------------------------+----------------------------+
-            | --input_ts='-' --columns=4,1      | read column 4 and 1 from   |
-            |                                   | standard input (stdin)     |
-            +-----------------------------------+----------------------------+
+            +-----------------------------------+-----------------------------+
+            | Keyword Example                   | Description                 |
+            +===================================+=============================+
+            | --input_ts=fname.csv              | read all columns from       |
+            |                                   | 'fname.csv'                 |
+            +-----------------------------------+-----------------------------+
+            | --input_ts=fname.csv,2,1          | read data columns 2 and 1   |
+            |                                   | from 'fname.csv'            |
+            +-----------------------------------+-----------------------------+
+            | --input_ts=fname.csv,2,skiprows=2 | read data column 2 from     |
+            |                                   | 'fname.csv', skipping first |
+            |                                   | 2 rows so header is read    |
+            |                                   | from third row              |
+            +-----------------------------------+-----------------------------+
+            | --input_ts=fname.xlsx,2,Sheet21   | read all data from 2nd      |
+            |                                   | sheet all data from         |
+            |                                   | "Sheet21" of 'fname.xlsx'   |
+            +-----------------------------------+-----------------------------+
+            | --input_ts=fname.hdf5,Table12,T2  | read all data from table    |
+            |                                   | "Table12" then all data     |
+            |                                   | from table "T2" of          |
+            |                                   | 'fname.hdf5'                |
+            +-----------------------------------+-----------------------------+
+            | --input_ts=fname.wdm,210,110      | read DSNs 210, then 110     |
+            |                                   | from 'fname.wdm'            |
+            +-----------------------------------+-----------------------------+
+            | --input_ts='-'                    | read all columns from       |
+            |                                   | standard input (stdin)      |
+            +-----------------------------------+-----------------------------+
+            | --input_ts='-' --columns=4,1      | read column 4 and 1 from    |
+            |                                   | standard input (stdin)      |
+            +-----------------------------------+-----------------------------+
 
         If working with CSV or TSV files you can use redirection rather than
         use `--input_ts=fname.csv`.  The following are identical:
@@ -784,14 +784,12 @@ def parsedate(
 
     Used for start and end dates.
     """
-
+    # The API should boomerang a datetime.datetime instance and None.
     if dstr is None:
         return dstr
-
-    # The API should boomerang a datetime.datetime instance and None.
-
     if isinstance(dstr, datetime.datetime):
         return dstr if strftime is None else dstr.strftime(strftime)
+
     try:
         pdate = pd.to_datetime(dstr)
     except ValueError:
@@ -811,17 +809,6 @@ def parsedate(
     return pdate.strftime(strftime)
 
 
-@validate_arguments
-def merge_dicts(*dict_args: dict) -> dict:
-    """Merge multiple dictionaries."""
-    result = {}
-
-    for dic in dict_args:
-        result.update(dic)
-
-    return result
-
-
 def about(name):
     """Print generic 'about' information used across all toolboxes."""
 
@@ -863,31 +850,10 @@ def _pick_column_or_value(tsd, var):
     return var
 
 
-def make_list(*strorlist, **kwds: Any) -> Any:
+def make_list(
+    *strorlist, n: Optional[int] = None, sep: str = ",", flat: bool = True
+) -> Any:
     """Normalize strings, converting to numbers or lists."""
-    try:
-        cnt = kwds.pop("n")
-    except KeyError:
-        cnt = None
-
-    if cnt is not None:
-        cnt = int(cnt)
-
-    try:
-        sep = kwds.pop("sep")
-    except KeyError:
-        sep = ","
-
-    try:
-        kwdname = kwds.pop("kwdname")
-    except KeyError:
-        kwdname = ""
-
-    try:
-        flat = kwds.pop("flat")
-    except KeyError:
-        flat = True
-
     if isinstance(strorlist, (list, tuple)):
         # The following will fix ((tuples, in, a, tuple, problem),)
 
@@ -899,19 +865,6 @@ def make_list(*strorlist, **kwds: Any) -> Any:
             # further processing.
             strorlist = strorlist[0]
 
-    if (
-        isinstance(strorlist, (list, tuple))
-        and cnt is not None
-        and len(strorlist) != cnt
-    ):
-        raise ValueError(
-            error_wrapper(
-                f"""
-                The list {strorlist} for "{kwdname}" should have {cnt} members
-                according to function requirements. """
-            )
-        )
-
     if isinstance(strorlist, pd.DataFrame):
         return [strorlist]
 
@@ -920,36 +873,30 @@ def make_list(*strorlist, **kwds: Any) -> Any:
 
     if strorlist is None or isinstance(strorlist, (type(None))):
         # None -> None
-        #
-
         return None
 
     if isinstance(strorlist, (int, float)):
         # 1      -> [1]
         # 1.2    -> [1.2]
-        #
 
-        return [strorlist]
+        strorlist = [strorlist]
 
     if isinstance(strorlist, (str, bytes)):
         if strorlist in ("None", "", b"None", b""):
             # 'None' -> None
             # ''     -> None
-            #
-
             return None
 
+        # Anything other than a scalar int or float continues.
         # '1'   -> [1]
         # '5.7' -> [5.7]
-
-        # Anything other than a scalar int or float continues.
-        #
         try:
             return [int(strorlist)]
         except ValueError:
             with suppress(ValueError):
                 return [float(strorlist)]
-        # Deal with a str or bytes.
+
+        # Deal with str or bytes.
         strorlist = strorlist.strip()
 
         if isinstance(strorlist, str):
@@ -965,16 +912,16 @@ def make_list(*strorlist, **kwds: Any) -> Any:
     if isinstance(strorlist, (StringIO, BytesIO)):
         return strorlist
 
-    if cnt is None:
-        cnt = len(strorlist)
-
     # At this point 'strorlist' variable should be a list or tuple.
 
-    if len(strorlist) != cnt:
+    if n is None:
+        n = len(strorlist)
+
+    if len(strorlist) != n:
         raise ValueError(
             error_wrapper(
                 f"""
-                The list {strorlist} for "{kwdname}" should have {cnt} members
+                The list {strorlist} should have {n} members
                 according to function requirements. """
             )
         )
@@ -1303,7 +1250,7 @@ def common_kwds(
     # to "no".  Discovered this after implementation and should deprecate
     # and remove in the future.
 
-    if por:
+    if por or force_freq:
         dropna = "no"
 
     ntsd = read_iso_ts(
@@ -1521,12 +1468,13 @@ def asbestfreq(data: DataFrame, force_freq: Optional[str] = None) -> DataFrame:
         raise ValueError(
             error_wrapper(
                 f"""
-Duplicate or time reversal index entry at record {np.where(ndiff <= 0)[0][0] + 1} (start count at 0):
-"{data.index[:-1][ndiff <= 0][0]}".
+                Duplicate or time reversal index entry at record
+                {np.where(ndiff <= 0)[0][0] + 1} (start count at 0):
+                "{data.index[:-1][ndiff <= 0][0]}".
 
-Perhaps use the "--clean" keyword on the CLI or "clean=True" if using
-Python or edit the input data..
-"""
+                Perhaps use the "--clean" keyword on the CLI or "clean=True" if
+                using Python or edit the input data..
+                """
             )
         )
 
@@ -1616,7 +1564,7 @@ Python or edit the input data..
 def dedup_index(
     idx: List[str], fmt: Optional[Any] = None, ignore_first: bool = True
 ) -> Index:
-    """Remove duplicates values in list.
+    """Remove duplicate values in list.
 
     Parameters
     ----------
@@ -1795,11 +1743,9 @@ printiso = _printiso
 
 
 def open_local(filein: str) -> TextIOWrapper:
-    """
-    Open the given input file.
+    """Open the given input file.
 
     It can decode various formats too, such as gzip and bz2.
-
     """
     base, ext = os.path.splitext(os.path.basename(filein))
 
@@ -1985,7 +1931,7 @@ def read_iso_ts(
 
     for source_index, source in enumerate(sources):
         res = pd.DataFrame()
-        parameters = make_list(source, sep=",")
+        parameters = make_list(source)
 
         if isinstance(parameters, list) and len(parameters) > 0:
             fname = parameters.pop(0)
